// include/signal_handler.h

#ifndef SIGNAL_HANDLER_H
#define SIGNAL_HANDLER_H

#include <signal.h>  // For sig_atomic_t
#include <stdbool.h> // For bool return type

// Platform-specific includes needed for HANDLE
#ifdef _WIN32
#include <windows.h> // <-- Added for HANDLE type
#endif

// --- Global Variable Declaration ---
// Declare the flag as extern so other modules can see it.
// It must be defined in exactly one source file (signal_handler.c).
extern volatile sig_atomic_t g_shutdown_requested;

#ifdef _WIN32
// Declare the Windows-specific shutdown event handle
// Used to interrupt blocking waits (like WaitForMultipleObjects)
extern HANDLE g_hShutdownEvent;
#endif

// --- Function Prototypes ---

/**
 * @brief Sets up the signal handlers for graceful shutdown (e.g., SIGINT/Ctrl+C).
 *        Uses platform-specific mechanisms (sigaction on POSIX, SetConsoleCtrlHandler on Windows).
 *        On Windows, also creates a manual-reset event (g_hShutdownEvent) used for interruption.
 *
 * @return true if handlers were set successfully (or likely successfully),
 *         false if a critical error occurred during setup (e.g., event creation failed).
 *         Warnings for non-critical issues might be printed directly via print_stderr.
 */
bool setup_signal_handlers(void);

#endif // SIGNAL_HANDLER_H
