// include/two_resamplers.h

#ifndef TWO_RESAMPLERS_H
#define TWO_RESAMPLERS_H

#include "input.h" // For UserInputs struct (which includes SearchMode, IntermediatePriority etc.)
#include "utils.h" // For StatusCode

// --- Function Prototypes ---

/**
 * @brief Prompts user with context and executes the two-stage rational resampler search.
 *
 * This function orchestrates the two-stage search based on the configuration
 * provided in the `inputs` struct (search mode, limits, constraints, intermediate target).
 * It calls the core search logic (`perform_two_stage_search` internally) and
 * then prints the formatted results or a failure message.
 * Checks the global shutdown flag throughout the process.
 * **User-facing prompts and output format remain unchanged.**
 *
 * @param inputs Pointer to the UserInputs struct containing all configuration parameters.
 *
 * @return StatusCode indicating the overall result:
 *         - SUCCESS: A suitable two-stage solution was found according to the criteria.
 *         - FAILURE: No suitable solution was found meeting the constraints/criteria,
 *                    or the operation was cancelled by the user, or shutdown was requested.
 *         - ERR_MEMORY_ALLOC, ERR_CALCULATION, ERR_OVERFLOW, ERR_INVALID_INPUT etc.,
 *           on specific critical errors encountered during the search or setup.
 */
StatusCode prompt_and_run_two_resamplers(const UserInputs* inputs);


#endif // TWO_RESAMPLERS_H
